



if not exist %LIBRARY_INC%\\apr_iconv.h       exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_BIN%\\libapriconv-1.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_LIB%\\libapriconv-1.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_BIN%\\iconv\\utf-8.so   exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
